AssemblyError

Enum AssemblyError 

pub enum AssemblyError {
Show 53 variants AllMarker {}, ArchitectureDirectiveIgnored { src: Arc<AssemblyCode>, location: SourceSpan, }, DuplicateStartpos { src: Arc<AssemblyCode>, location: SourceSpan, }, MissingStartpos { src: Arc<AssemblyCode>, }, InvalidArchitectureDirective { arch: SharedStr, src: Arc<AssemblyCode>, location: SourceSpan, }, MathPriForbidden { src: Arc<AssemblyCode>, location: SourceSpan, }, AssigningToReference { name: SharedStr, kind: UnassignableReferenceType, src: Arc<AssemblyCode>, location: SourceSpan, }, UsingMacroArgumentOutsideMacro { name: SharedStr, src: Arc<AssemblyCode>, location: SourceSpan, }, RecursiveMacroDefinition { name: SharedStr, src: Arc<AssemblyCode>, location: SourceSpan, outer: SourceSpan, }, DirectiveRecursionLimit { name: SharedStr, depth: usize, src: Arc<AssemblyCode>, location: SourceSpan, }, UnknownMacroArgument { name: SharedStr, available_names: Vec<SharedStr>, src: Arc<AssemblyCode>, location: SourceSpan, }, UndefinedUserMacro { name: SharedStr, available_macros: Vec<SharedStr>, src: Arc<AssemblyCode>, location: SourceSpan, }, IncorrectNumberOfMacroArguments { name: SharedStr, expected_number: usize, actual_number: usize, src: Arc<AssemblyCode>, location: SourceSpan, definition: SourceSpan, }, FileNotFound { os_error: Arc<Error>, file_name: SharedStr, src: Arc<AssemblyCode>, location: SourceSpan, }, IncludeCycle { cycle_trigger_file: SharedStr, src: Arc<AssemblyCode>, include: SourceSpan, }, AudioProcessingError { error_text: SharedStr, file_name: SharedStr, src: Arc<AssemblyCode>, location: SourceSpan, }, SegmentMismatch { segment_start: MemoryAddress, segment_end: MemoryAddress, location: SourceSpan, src: Arc<AssemblyCode>, }, MissingSegment { location: SourceSpan, src: Arc<AssemblyCode>, }, ReferenceOutsideSegment { reference: SharedStr, location: SourceSpan, src: Arc<AssemblyCode>, }, NoSegmentOnStack { location: SourceSpan, src: Arc<AssemblyCode>, }, UnresolvedReference { reference: SharedStr, reference_location: Option<SourceSpan>, usage_location: SourceSpan, src: Arc<AssemblyCode>, }, RedefinedReference { reference: SharedStr, reference_location: SourceSpan, redefine_location: SourceSpan, src: Arc<AssemblyCode>, }, UnresolvedMacroGlobal { usage_location: SourceSpan, src: Arc<AssemblyCode>, }, RepeatCountOutsideRepeat { usage_location: SourceSpan, src: Arc<AssemblyCode>, }, NegativeRepeatCount { repeatcount_location: SourceSpan, resolved_repeatcount: MemoryAddress, directive_location: SourceSpan, src: Arc<AssemblyCode>, }, InvalidFirstAddressingMode { mode: SharedStr, mnemonic: Mnemonic, legal_modes: Vec<SharedStr>, src: Arc<AssemblyCode>, location: SourceSpan, }, InvalidSecondAddressingMode { mode: SharedStr, mnemonic: Mnemonic, first_mode: SharedStr, legal_modes: Vec<SharedStr>, src: Arc<AssemblyCode>, location: SourceSpan, }, TwoOperandsNotAllowed { mnemonic: Mnemonic, src: Arc<AssemblyCode>, location: SourceSpan, }, OperandNotAllowed { mnemonic: Mnemonic, location: SourceSpan, src: Arc<AssemblyCode>, }, MissingOperand { mnemonic: Mnemonic, legal_modes: Vec<SharedStr>, location: SourceSpan, src: Arc<AssemblyCode>, }, MissingSecondOperand { mnemonic: Mnemonic, legal_modes: Vec<SharedStr>, location: SourceSpan, src: Arc<AssemblyCode>, }, InvalidConstant { constant: SharedStr, typename: SharedStr, src: Arc<AssemblyCode>, location: SourceSpan, }, ReferencesInDirectiveArgument { directive: DirectiveSymbol, src: Arc<AssemblyCode>, location: SourceSpan, argument_location: SourceSpan, }, MissingGlobalLabel { local_label: SharedStr, src: Arc<AssemblyCode>, location: SourceSpan, }, StartAboveEnd { start: usize, end: usize, src: Arc<AssemblyCode>, location: SourceSpan, }, RangeOutOfBounds { start: usize, end: usize, file: SharedStr, file_len: usize, src: Arc<AssemblyCode>, location: SourceSpan, }, InvalidDirectiveOption { option: SharedStr, directive: SharedStr, valid_options: Vec<SharedStr>, src: Arc<AssemblyCode>, directive_location: SourceSpan, option_location: SourceSpan, }, MissingFillParameter { operation: SharedStr, is_fill: bool, location: SourceSpan, src: Arc<AssemblyCode>, }, SampleTableTooLarge { entry_count: usize, src: Arc<AssemblyCode>, directive_location: SourceSpan, }, UnalignedSampleTable { memory_address: MemoryAddress, src: Arc<AssemblyCode>, location: SourceSpan, }, ExpectedToken { expected: SharedStr, actual: Token, location: SourceSpan, src: Arc<AssemblyCode>, }, ExpectedTokens { expected: Vec<SharedStr>, actual: Token, location: SourceSpan, src: Arc<AssemblyCode>, }, InvalidNumber { error: ParseIntError, location: SourceSpan, src: Arc<AssemblyCode>, }, NumberIdentifier { text: SharedStr, error: ParseIntError, location: SourceSpan, src: Arc<AssemblyCode>, }, ImplicitBitIndex { mnemonic: Mnemonic, location: SourceSpan, src: Arc<AssemblyCode>, }, UnexpectedEndOfTokens { expected: Vec<SharedStr>, location: SourceSpan, src: Arc<AssemblyCode>, }, UnexpectedCharacter { chr: char, location: SourceSpan, src: Arc<AssemblyCode>, }, InvalidBitIndex { index: u8, location: SourceSpan, src: Arc<AssemblyCode>, }, UnresolvableValue { value: AssemblyTimeValue, value_location: SourceSpan, src: Arc<AssemblyCode>, }, ValueTooLarge { value: MemoryAddress, size: u8, location: SourceSpan, src: Arc<AssemblyCode>, }, RelativeOffsetTooLarge { target: MemoryAddress, address: MemoryAddress, location: SourceSpan, target_location: Option<SourceSpan>, src: Arc<AssemblyCode>, }, NonDirectPageReference { name: SharedStr, address: MemoryAddress, reference_definition: SourceSpan, usage_location: SourceSpan, src: Arc<AssemblyCode>, }, OtherIoError { inner: Arc<Error>, },
}
All types of errors that the assembler can report to the user.

Variants



AllMarker

Marker error for allowing the user to pass –ignore all or –error all on the CLI.



ArchitectureDirectiveIgnored

Fields

location: SourceSpan


DuplicateStartpos

Fields

location: SourceSpan


MissingStartpos

Fields



InvalidArchitectureDirective

Fields

location: SourceSpan


MathPriForbidden

Fields

location: SourceSpan


AssigningToReference

Fields

kind: UnassignableReferenceType
location: SourceSpan


UsingMacroArgumentOutsideMacro

Fields

location: SourceSpan


RecursiveMacroDefinition

Fields

location: SourceSpan


DirectiveRecursionLimit

Fields

depth: usize
location: SourceSpan


UnknownMacroArgument

Fields

available_names: Vec<SharedStr>
location: SourceSpan


UndefinedUserMacro

Fields

available_macros: Vec<SharedStr>
location: SourceSpan


IncorrectNumberOfMacroArguments

Fields

expected_number: usize
actual_number: usize
location: SourceSpan
definition: SourceSpan


FileNotFound

Fields

os_error: Arc<Error>

std::io::Error is not clonable for performance and implementation detail reasonsrustissue.

file_name: SharedStr
location: SourceSpan


IncludeCycle

Fields

cycle_trigger_file: SharedStr
include: SourceSpan


AudioProcessingError

Fields

error_text: SharedStr
file_name: SharedStr
location: SourceSpan


SegmentMismatch

Fields

segment_start: MemoryAddress
segment_end: MemoryAddress
location: SourceSpan


MissingSegment

Fields

location: SourceSpan


ReferenceOutsideSegment

Fields

reference: SharedStr
location: SourceSpan


NoSegmentOnStack

Fields

location: SourceSpan


UnresolvedReference

Fields

reference: SharedStr
reference_location: Option<SourceSpan>
usage_location: SourceSpan


RedefinedReference

Fields

reference: SharedStr
reference_location: SourceSpan
redefine_location: SourceSpan


UnresolvedMacroGlobal

Fields

usage_location: SourceSpan


RepeatCountOutsideRepeat

Fields

usage_location: SourceSpan


NegativeRepeatCount

Fields

repeatcount_location: SourceSpan
resolved_repeatcount: MemoryAddress
directive_location: SourceSpan


InvalidFirstAddressingMode

Fields

mnemonic: Mnemonic
legal_modes: Vec<SharedStr>
location: SourceSpan


InvalidSecondAddressingMode

Fields

mnemonic: Mnemonic
first_mode: SharedStr
legal_modes: Vec<SharedStr>
location: SourceSpan


TwoOperandsNotAllowed

Fields

mnemonic: Mnemonic
location: SourceSpan


OperandNotAllowed

Fields

mnemonic: Mnemonic
location: SourceSpan


MissingOperand

Fields

mnemonic: Mnemonic
legal_modes: Vec<SharedStr>
location: SourceSpan


MissingSecondOperand

Fields

mnemonic: Mnemonic
legal_modes: Vec<SharedStr>
location: SourceSpan


InvalidConstant

Fields

constant: SharedStr
typename: SharedStr
location: SourceSpan


ReferencesInDirectiveArgument

Fields

directive: DirectiveSymbol
location: SourceSpan
argument_location: SourceSpan


MissingGlobalLabel

Fields

local_label: SharedStr
location: SourceSpan


StartAboveEnd

Fields

start: usize
end: usize
location: SourceSpan


RangeOutOfBounds

Fields

start: usize
end: usize
file_len: usize
location: SourceSpan


InvalidDirectiveOption

Fields

option: SharedStr
directive: SharedStr
valid_options: Vec<SharedStr>
directive_location: SourceSpan
option_location: SourceSpan


MissingFillParameter

Fields

operation: SharedStr
is_fill: bool
location: SourceSpan


SampleTableTooLarge

Fields

entry_count: usize
directive_location: SourceSpan


UnalignedSampleTable

Fields

memory_address: MemoryAddress
location: SourceSpan


ExpectedToken

Fields

expected: SharedStr
actual: Token
location: SourceSpan


ExpectedTokens

Fields

expected: Vec<SharedStr>
actual: Token
location: SourceSpan


InvalidNumber

Fields

location: SourceSpan


NumberIdentifier



ImplicitBitIndex

Fields

mnemonic: Mnemonic
location: SourceSpan


UnexpectedEndOfTokens

Fields

expected: Vec<SharedStr>
location: SourceSpan


UnexpectedCharacter

Fields

chr: char
location: SourceSpan


InvalidBitIndex

Fields

index: u8
location: SourceSpan


UnresolvableValue

Fields

value_location: SourceSpan


ValueTooLarge

Fields

size: u8
location: SourceSpan


RelativeOffsetTooLarge

Fields

location: SourceSpan
target_location: Option<SourceSpan>


NonDirectPageReference

Fields

reference_definition: SourceSpan
usage_location: SourceSpan


OtherIoError

Fields

inner: Arc<Error>